Documentation
¶
Index ¶
- Variables
- func KeyFromValue(value string) (string, []uuid.UUID)
- type Feats
- type RelationalNode
- type Silk
- func (silk *Silk) CloseDatabase()
- func (silk *Silk) FindDiskDatabase(dir string)
- func (silk *Silk) NewDatabase(basedir string, feats int) (string, error)
- func (silk *Silk) OpenDatabase(dir string, name string, feats int) error
- func (silk *Silk) PullNode(uuid string) RelationalNode
- func (silk *Silk) PushNode(node RelationalNode)
Constants ¶
This section is empty.
Variables ¶
var (
FEATS = Feats{
AppendOnly: 1 << 0,
Lz4: 1 << 2,
SplayTree: 1 << 1,
AolFflush: 1 << 3,
}
)
declare magic feature choices
Functions ¶
Types ¶
type RelationalNode ¶
type RelationalNode struct {
Chunks []uuid.UUID
Key string //UWUID
Name string
Links []string
Backlinks []string
Tags []string
}
func NewRelationalNode ¶
func NewRelationalNode(value string) *RelationalNode
type Silk ¶
type Silk struct {
// contains filtered or unexported fields
}
onto the main struct
func (*Silk) CloseDatabase ¶
func (silk *Silk) CloseDatabase()
close a database, used internally and externally
func (*Silk) FindDiskDatabase ¶
find me all valid databases in a directory
func (*Silk) NewDatabase ¶
give me a random database here and switch me to it
func (*Silk) OpenDatabase ¶
open a database in a directory I know exists (currently creates a database if it doesn't exist, as long as the dir exists)
func (*Silk) PullNode ¶
func (silk *Silk) PullNode(uuid string) RelationalNode
func (*Silk) PushNode ¶
func (silk *Silk) PushNode(node RelationalNode)
Click to show internal directories.
Click to hide internal directories.